==> glfw-doc-3.3.9-1-aarch64.pkg.tar.xz: usr/share/doc/glfw/html/search/all_f.js <==
var searchData=
[
  ['lack_20alpha_20channel_20on_20older_20wayland_20systems_0',['Frambuffer may lack alpha channel on older Wayland systems',['../news.html#wayland_alpha_34',1,'']]],
  ['later_20is_20required_1',['CMake 3.0 or later is required',['../news.html#cmake_version_33',1,'']]],
  ['layout_20of_20joysticks_20have_20changed_2',['Layout of joysticks have changed',['../news.html#joystick_layout_33',1,'']]],
  ['leave_20callback_3',['Cursor enter/leave callback',['../news.html#news_30_enterleave',1,'']]],
  ['leave_20events_4',['Cursor enter/leave events',['../input_guide.html#cursor_enter',1,'']]],
  ['less_20windows_5',['Context-less windows',['../news.html#news_32_noapi',1,'']]],
  ['lib_5fsuffix_6',['CMake option LIB_SUFFIX',['../news.html#lib_suffix_33',1,'']]],
  ['libdecor_20decorations_7',['Wayland libdecor decorations',['../news.html#wayland_libdecor_33',1,'']]],
  ['libraries_8',['Link with the right libraries',['../build_guide.html#build_link',1,'']]],
  ['libraries_20are_20loaded_20dynamically_9',['X11 extension libraries are loaded dynamically',['../news.html#x11_linking_33',1,'']]],
  ['library_10',['library',['../compile_guide.html#compile_compile',1,'Compiling the library'],['../context_guide.html#context_glext_auto',1,'Loading extension with a loader library']]],
  ['library_20and_20header_20file_11',['Renamed library and header file',['../moving_guide.html#moving_renamed_files',1,'']]],
  ['lifetimes_12',['Pointer lifetimes',['../intro_guide.html#lifetime',1,'']]],
  ['like_20systems_13',['like systems',['../compile_guide.html#compile_deps_wayland',1,'Dependencies for Wayland on Unix-like systems'],['../compile_guide.html#compile_deps_x11',1,'Dependencies for X11 on Unix-like systems']]],
  ['limit_20support_14',['Window size limit support',['../news.html#news_32_sizelimits',1,'']]],
  ['limitations_15',['Guarantees and limitations',['../intro_guide.html#guarantees_limitations',1,'']]],
  ['limits_16',['limits',['../window_guide.html#window_sizelimits',1,'Window size limits'],['../news.html#x11_clipboard_33',1,'X11 clipboard transfer limits']]],
  ['line_20on_20macos_17',['With command-line on macOS',['../build_guide.html#build_link_osx',1,'']]],
  ['line_20tool_18',['Generating files with the CMake command-line tool',['../compile_guide.html#compile_generate_cli',1,'']]],
  ['link_20with_20the_20right_20libraries_19',['Link with the right libraries',['../build_guide.html#build_link',1,'']]],
  ['linking_20against_20the_20vulkan_20loader_20',['Linking against the Vulkan loader',['../vulkan_guide.html#vulkan_loader',1,'']]],
  ['list_21',['Deprecated List',['../deprecated.html',1,'']]],
  ['loaded_20dynamically_22',['X11 extension libraries are loaded dynamically',['../news.html#x11_linking_33',1,'']]],
  ['loader_23',['Linking against the Vulkan loader',['../vulkan_guide.html#vulkan_loader',1,'']]],
  ['loader_20and_20api_24',['Vulkan loader and API',['../compat_guide.html#compat_vulkan',1,'']]],
  ['loader_20library_25',['Loading extension with a loader library',['../context_guide.html#context_glext_auto',1,'']]],
  ['loading_26',['Removal of image and texture loading',['../moving_guide.html#moving_image',1,'']]],
  ['loading_20extension_20with_20a_20loader_20library_27',['Loading extension with a loader library',['../context_guide.html#context_glext_auto',1,'']]],
  ['loading_20extensions_20manually_28',['Loading extensions manually',['../context_guide.html#context_glext_manual',1,'']]],
  ['localized_20key_20names_29',['Localized key names',['../news.html#news_32_keyname',1,'']]],
  ['longer_20roundtrip_20to_20server_30',['Empty events on X11 no longer roundtrip to server',['../news.html#emptyevents_33',1,'']]],
  ['lunarg_20vulkan_20sdk_20dependency_31',['LunarG Vulkan SDK dependency',['../news.html#vulkan_sdk_33',1,'']]]
];

==> glfw-doc-3.3.10-1-aarch64.pkg.tar.xz: usr/share/doc/glfw/html/search/all_f.js <==
var searchData=
[
  ['lack_20alpha_20channel_20on_20older_20wayland_20systems_0',['Framebuffer may lack alpha channel on older Wayland systems',['../news.html#wayland_alpha_33',1,'']]],
  ['later_20is_20required_1',['CMake 3.0 or later is required',['../news.html#cmake_version_33',1,'']]],
  ['layout_20of_20joysticks_20have_20changed_2',['Layout of joysticks have changed',['../news.html#joystick_layout_33',1,'']]],
  ['leave_20callback_3',['Cursor enter/leave callback',['../news.html#news_30_enterleave',1,'']]],
  ['leave_20events_4',['Cursor enter/leave events',['../input_guide.html#cursor_enter',1,'']]],
  ['less_20windows_5',['Context-less windows',['../news.html#news_32_noapi',1,'']]],
  ['lib_5fsuffix_6',['CMake option LIB_SUFFIX',['../news.html#lib_suffix_33',1,'']]],
  ['libdecor_20decorations_7',['Wayland libdecor decorations',['../news.html#wayland_libdecor_33',1,'']]],
  ['libraries_8',['Link with the right libraries',['../build_guide.html#build_link',1,'']]],
  ['libraries_20are_20loaded_20dynamically_9',['X11 extension libraries are loaded dynamically',['../news.html#x11_linking_33',1,'']]],
  ['library_10',['Library',['../compile_guide.html#compile_compile',1,'Compiling the library'],['../context_guide.html#context_glext_auto',1,'Loading extension with a loader library']]],
  ['library_20and_20header_20file_11',['Renamed library and header file',['../moving_guide.html#moving_renamed_files',1,'']]],
  ['lifetimes_12',['Pointer lifetimes',['../intro_guide.html#lifetime',1,'']]],
  ['like_20systems_13',['Like systems',['../compile_guide.html#compile_deps_wayland',1,'Dependencies for Wayland on Unix-like systems'],['../compile_guide.html#compile_deps_x11',1,'Dependencies for X11 on Unix-like systems']]],
  ['limit_20support_14',['Window size limit support',['../news.html#news_32_sizelimits',1,'']]],
  ['limitations_15',['Guarantees and limitations',['../intro_guide.html#guarantees_limitations',1,'']]],
  ['limits_16',['Limits',['../window_guide.html#window_sizelimits',1,'Window size limits'],['../news.html#x11_clipboard_33',1,'X11 clipboard transfer limits']]],
  ['line_20or_20makefile_20on_20macos_17',['With command-line or makefile on macOS',['../build_guide.html#build_link_osx',1,'']]],
  ['line_20tool_18',['Generating files with the CMake command-line tool',['../compile_guide.html#compile_generate_cli',1,'']]],
  ['link_20with_20the_20right_20libraries_19',['Link with the right libraries',['../build_guide.html#build_link',1,'']]],
  ['linking_20against_20the_20vulkan_20loader_20',['Linking against the Vulkan loader',['../vulkan_guide.html#vulkan_loader',1,'']]],
  ['list_21',['Deprecated List',['../deprecated.html',1,'']]],
  ['loaded_20dynamically_22',['X11 extension libraries are loaded dynamically',['../news.html#x11_linking_33',1,'']]],
  ['loader_23',['Linking against the Vulkan loader',['../vulkan_guide.html#vulkan_loader',1,'']]],
  ['loader_20and_20api_24',['Vulkan loader and API',['../compat_guide.html#compat_vulkan',1,'']]],
  ['loader_20library_25',['Loading extension with a loader library',['../context_guide.html#context_glext_auto',1,'']]],
  ['loading_26',['Removal of image and texture loading',['../moving_guide.html#moving_image',1,'']]],
  ['loading_20extension_20with_20a_20loader_20library_27',['Loading extension with a loader library',['../context_guide.html#context_glext_auto',1,'']]],
  ['loading_20extensions_20manually_28',['Loading extensions manually',['../context_guide.html#context_glext_manual',1,'']]],
  ['localized_20key_20names_29',['Localized key names',['../news.html#news_32_keyname',1,'']]],
  ['longer_20roundtrip_20to_20server_30',['Empty events on X11 no longer roundtrip to server',['../news.html#emptyevents_33',1,'']]],
  ['lunarg_20vulkan_20sdk_20dependency_31',['LunarG Vulkan SDK dependency',['../news.html#vulkan_sdk_33',1,'']]]
];
